// gulp/tasks/base/clean.js
'use strict';

// ----------------------------------
// available tasks: 
//    'gulp clean'       : clean production folder & caches
//    'gulp clean:prod'  : clean production folder
//    'gulp clean:dev'   : clean development folder
//    'gulp clean:cache' : clear all caches
// ----------------------------------
// plugins:
//     del        : $.del
//     gulp-cached: $.cached
// ----------------------------------
// config:
//     config.task.clean : task name
// ----------------------------------

module.exports = function(gulp, $, path, config) {

    // clear all caches enough
    gulp.task(config.task.clean + ':cache', 'clear all caches', function() {

        $.cached.caches = {};

    });

    // delete production folder [build/prod]
    gulp.task(config.task.clean + ':prod', 'delete production folder [build/prod]', function() {

        return $.del([
            path.to.dist.prod
        ]);

    });

    // delete development folder [build/dev]
    gulp.task(config.task.clean + ':dev', 'delete development folder [build/dev]', function() {

        return $.del([
            path.to.dist.dev
        ]);

    });

    // delete dest folder [build] and clear all caches
    gulp.task(config.task.clean, 'delete dest folder [build] and clear all caches \n', [config.task.clean + ':cache'], function() {

        return $.del([
            path.to.dist.main,
            // this file created from images:favicons task
            // in source/templates/includes/ >> default [favicons.nunjucks]
            config.images.faviconsOptions.html
        ]);

    });

};