// gulp/tasks/build/html.js
'use strict';

// ----------------------------------
// available tasks:
//    'gulp build:nunjucks'    : render nunjucks for build
//    'gulp build:inject'      : inject files with paths for useref
//    'gulp build:html'        : minify html
// ----------------------------------
// plugins:
//      gulp-htmlmin : $.htmlmin
//      gulp-plumber : $.plumber
// ----------------------------------
// config:
//     config.task.build : task name
// ----------------------------------

module.exports = function(gulp, $, path, config, fs) {

  var wiredep = $.wiredep.stream;

  // render nunjucks files
  gulp.task(config.task.build + ':render', 'render nunjucks templates', function() {

    $.nunjucksRender.nunjucks.configure([path.to.nunjucks.config], {
      // disable nunjucksRender watch option
      watch: false
    });

    return gulp.src(path.to.nunjucks.src)
      //prevent breaking error
      .pipe($.plumber({
        errorHandler: config.error
      }))
      // add data from data.json
      .pipe($.data(function(){
        return JSON.parse(fs.readFileSync(path.to.json.data))
      }))
      // start render
      .pipe($.nunjucksRender())
      .pipe(gulp.dest(path.to.dist.prod))
  });

  // inject css and js files for build
  gulp.task(config.task.build + ':inject', 'inject js files into the html', function(){

    return gulp.src(path.to.dist.prod + '*.html')
      //prevent breaking error
      .pipe($.plumber({
        errorHandler: config.error
      }))

      /************************
            CSS FILES
      ************************/
      .pipe($.inject(gulp.src(
          path.to.scss.dist.dev + '/*.css', {
            read: false
          }),
          config.nunjucks.inject.options
      ))
      /************************
              JS FILES
      ************************/
      .pipe($.inject(gulp.src(
        path.to.js.dist.dev + '/*.js', {
          read: false
        }),
        config.html.inject.options
      ))
      /************************
          BOWER DEPENDENCIES
      ************************/
      .pipe(wiredep())
      .pipe(gulp.dest(path.to.dist.prod))
  });

    // copy & minfy html files task
    gulp.task(config.task.build + ':html', 'minify html files', function() {

        return gulp.src(path.to.dist.prod + '**/*.html')
            // prevent breaking errors
            .pipe($.plumber({
                errorHandler: config.error
            }))

            // minify HTML
            .pipe($.htmlmin(
                config.html.htmlminOptions // options
            ))
            .pipe(gulp.dest(path.to.dist.prod));

    });

};