// gulp/tasks/default/images.js
'use strict';

// ----------------------------------
// available tasks: 
//    'gulp images'           : main images task
//    'gulp images:svgsprite' : create svg sprites
//    'gulp images:favicons'  : generate favicons
// ----------------------------------
// plugins:
//    gulp-plumber        : $.plumber
//    gulp-favicons       : $.favicons
//    gulp-rename         : $.rename
//    gulp-cheerio        : $.cheerio
//    gulp-svgmin         : $.svgmin
//    gulp-svgstore       : $.svgstore
// ----------------------------------
// config:
//     config.task.images : task name
// ----------------------------------

module.exports = function(gulp, $, path, config) {

    // require the ES5 file from gulp-favicons 
    var favicons = require('gulp-favicons/es5');

    // generate favicons task
    gulp.task(config.task.images + ':favicons', 'generate favicons', function() {

        return gulp.src(path.to.images.logo)
            // prevent breaking errors
            .pipe($.plumber({
                errorHandler: config.error
            }))
            // generate favicons
            .pipe(favicons(
                config.images.faviconsOptions // options
            ))
            .pipe(gulp.dest(path.to.images.dist.favicons));

    });

    // Make an SVG sprite.
    gulp.task(config.task.images + ':svgsprite', 'generate svg sprites', function() {

      return gulp.src(path.to.images.icons)
        .pipe($.svgmin())
        .pipe($.cheerio({
        run: function ($) {
          $('[fill]').removeAttr('fill');
          $('style').remove();
        },
        parserOptions: { xmlMode: true }
      }))
        
      .pipe($.rename({
        prefix: 'icon--'
      }))
      .pipe($.svgstore())
      .pipe(gulp.dest(path.to.images.dist.dev));
    });

    // main images task
    gulp.task(config.task.images, 'main images task', function(cb) {

        $.runSequence(
            config.task.images + ':favicons',
            config.task.iamges + ':svgsprite'
            cb
        )

    });

};