// gulp/tasks/default/nunjucks.js
'use strict';

// ----------------------------------
// available tasks: 
//    'gulp nunjucks'       : main task
//    'gulp nunjucks:render': render nunjucks files
//    'gulp nunjucks:inject': inject css/js files
// ----------------------------------
// plugins:
//     gulp-nunjucks-render: $.nunjucksRender
//     browser-sync        : $.browserSync
//     gulp-changed        : $.changed
//     gulp-newer          : $.newer
//     gulp-inject         : $.inject
//     gulp-plumber        : $.plumber
//     gulp-prettify       : $.prettify
//     wiredep             : $.wiredep
// ----------------------------------
// config:
//     config.task.nunjucks : task name
// ----------------------------------

module.exports = function(gulp, $, path, config, fs) {

  var wiredep = $.wiredep.stream;

  // render nunjucks files 
  gulp.task(config.task.nunjucks + ':render', 'render nunjucks templates', function() {

    $.nunjucksRender.nunjucks.configure([path.to.nunjucks.config], {
      // disable nunjucksRender watch option
      watch: false
    });

    return gulp.src(path.to.nunjucks.src)
      //prevent breaking error
      .pipe($.plumber({
        errorHandler: config.error
      }))
      // only pass through changed files
      .pipe($.changed(path.to.dist.dev + '*.html'))
      // only pass through newer source files
      .pipe($.newer(path.to.dist.dev + '*.html'))
      // add data from data.json
      .pipe($.data(function(){
        return JSON.parse(fs.readFileSync(path.to.json.data))
      }))
      // start render
      .pipe($.nunjucksRender())
      // beautify HTML
      .pipe($.prettify(
        config.html.prettifyOptions // options
      ))
      .pipe(gulp.dest(path.to.dist.dev))
      .pipe($.browserSync.reload({
        stream: true
      }));

  });

  // inject css and js files into the html
  gulp.task(config.task.nunjucks + ':inject', 'inject js files into the html', function(){

    return gulp.src(path.to.dist.dev + '*.html')
      //prevent breaking error
      .pipe($.plumber({
        errorHandler: config.error
      }))

      /************************
            CSS FILES
      ************************/
      .pipe($.inject(gulp.src(
          path.to.scss.dist.dev + '/*.css', {
            read: false
          }),
          config.nunjucks.inject.options
      ))
      /************************
              JS FILES
      ************************/
      .pipe($.inject(gulp.src(
        path.to.js.dist.dev + '/*.js', {
          read: false
        }),
        config.nunjucks.inject.options
      ))
      /************************
          BOWER DEPENDENCIES
      ************************/
      .pipe(wiredep(config.wiredep.dev))
      .pipe(gulp.dest(path.to.dist.dev))
      .pipe($.browserSync.reload({
        stream: true
      }));

  });

  // main nunjucks task
  gulp.task(config.task.nunjucks, 'main nunjucks task', function(cb) {
    $.runSequence(
      config.task.nunjucks + ':render',
      config.task.nunjucks + ':inject',
      cb
    )
  });

}