/*
 *    <%= projectName %>
 *    <%= projectDescription %>
 *    <%= projectVersion %>
 */

// gulpfile.js
'use strict';

// ----------------------------------
// available tasks: 
//    'gulp'
//
// ----------------------------------
// plugins:
//    browser-sync, browserify, del, gulp, gulp-autoprefixer,
//    gulp-cached, gulp-changed, gulp-cssnano, gulp-data, gulp-favicons
//    gulp-filter, gulp-flatten, gulp-help, gulp-htmlmin, gulp-imagemin,
//    gulp-inject, gulp-load-plugins, gulp-load-subtasks, gulp-newer,
//    gulp-nunjucks-render, gulp-plumber, gulp-prettify, gulp-print,
//    gulp-sass, gulp-sourcemaps, gulp-uglify, gulp-uncss, gulp-useref, 
//    gulp-util, gulp-webp, imagemin-pngquant, lazypipe, lodash.assign,
//    run-sequence, vinyl-buffer, vinyl-source-stream, watchify, wiredep
// ----------------------------------


// main gulp plugins

var gulp      = require('gulp-help')(require('gulp')),
    path      = require('./gulp/paths.js'),
    config    = require('./gulp/config.js'),
    fs        = require('fs'),
    sequence  = require('run-sequence'),
    $         = require('gulp-load-plugins')({
                  // used for all plugins not only gulp-*
                  pattern: '*',
                  rename: {
                    'lodash.assign': 'assign'
                  }
                });

// require all tasks
// require all tasks : gulp-load-subtasks
$.loadSubtasks('./gulp/tasks/**/*.js', $, path, config, fs);

// common default tasks : for dev mode
gulp.task('default', 'common default tasks for dev mode', function(cb) {
    sequence(
      config.task.clean,
      config.task.fonts,
      config.task.scss,
      config.task.scripts,
      config.task.images,
      config.task.nunjucks,
      config.task.browserSync,
      'watch',
      cb
    )
});

// build tasks : for prod mode
gulp.task(config.task.build, 'main build task for prod mode', function(cb) {
    sequence(
      config.task.clean + ':cache',
      config.task.clean + ':prod',
      [config.task.build + ':fonts', config.task.build + ':images'],
      config.task.build + ':render',
      config.task.build + ':inject',
      config.task.build + ':useref',
      [config.task.build + ':css', config.task.build + ':js'],
      config.task.build + ':html',
      <% if (slack) { %> 
      config.task.build + ':slack',
      <% } %>
      config.task.browserSync + ':prod',
      cb
    )
});